@@ -4,8 +4,8 @@
  * BSD-style license that can be found in the LICENSE file.
  */
 
-#ifndef INCLUDE_DART_NATIVE_API_H_
-#define INCLUDE_DART_NATIVE_API_H_
+#ifndef RUNTIME_INCLUDE_DART_NATIVE_API_H_
+#define RUNTIME_INCLUDE_DART_NATIVE_API_H_
 
 #include "include/dart_api.h"
 
@@ -176,4 +176,4 @@ DART_EXPORT Dart_Handle Dart_CompileAll();
  */
 DART_EXPORT Dart_Handle Dart_ParseAll();
 
-#endif  /* INCLUDE_DART_NATIVE_API_H_ */  /* NOLINT */
+#endif /* INCLUDE_DART_NATIVE_API_H_ */ /* NOLINT */
