@@ -26,7 +26,9 @@ import 'package:analysis_server/src/services/search/search_engine.dart';
 import 'package:analysis_server/src/services/search/search_engine_internal.dart';
 import 'package:analysis_server/src/services/search/search_engine_internal2.dart';
 import 'package:analysis_server/src/single_context_manager.dart';
+import 'package:analysis_server/src/utilities/null_string_sink.dart';
 import 'package:analyzer/dart/ast/ast.dart';
+import 'package:analyzer/dart/ast/standard_resolution_map.dart';
 import 'package:analyzer/dart/element/element.dart';
 import 'package:analyzer/exception/exception.dart';
 import 'package:analyzer/file_system/file_system.dart';
@@ -240,7 +242,7 @@ class AnalysisServer {
   /**
    * The controller that is notified when analysis is started.
    */
-  StreamController<AnalysisContext> _onAnalysisStartedController;
+  StreamController<bool> _onAnalysisStartedController;
 
   /**
    * The controller that is notified when a single file has been analyzed.
@@ -329,12 +331,6 @@ class AnalysisServer {
    */
   final Set<String> priorityFiles = new Set<String>();
 
-  /**
-   * The cached results for [priorityFiles].
-   * These results must have not `null` units.
-   */
-  final Map<String, nd.AnalysisResult> priorityFileResults = {};
-
   /**
    * Initialize a newly created server to receive requests from and send
    * responses to the given [channel].
@@ -367,7 +363,20 @@ class AnalysisServer {
         options.finerGrainedInvalidation;
     defaultContextOptions.generateImplicitErrors = false;
     operationQueue = new ServerOperationQueue();
-    _analysisPerformanceLogger = new nd.PerformanceLog(io.stdout);
+
+    {
+      String name = options.newAnalysisDriverLog;
+      StringSink sink = new NullStringSink();
+      if (name != null) {
+        if (name == 'stdout') {
+          sink = io.stdout;
+        } else if (name.startsWith('file:')) {
+          String path = name.substring('file:'.length);
+          sink = new io.File(path).openWrite(mode: io.FileMode.APPEND);
+        }
+      }
+      _analysisPerformanceLogger = new nd.PerformanceLog(sink);
+    }
     if (resourceProvider is PhysicalResourceProvider) {
       byteStore = new MemoryCachingByteStore(
           new FileByteStore(
@@ -381,6 +390,7 @@ class AnalysisServer {
         new nd.AnalysisDriverScheduler(_analysisPerformanceLogger);
     analysisDriverScheduler.status.listen(sendStatusNotificationNew);
     analysisDriverScheduler.start();
+
     if (useSingleContextManager) {
       contextManager = new SingleContextManager(resourceProvider, sdkManager,
           packageResolverProvider, analyzedFilesGlobs, defaultContextOptions);
@@ -482,9 +492,9 @@ class AnalysisServer {
   }
 
   /**
-   * The stream that is notified when analysis of a context is started.
+   * The stream that is notified with `true` when analysis is started.
    */
-  Stream<AnalysisContext> get onAnalysisStarted {
+  Stream<bool> get onAnalysisStarted {
     return _onAnalysisStartedController.stream;
   }
 
@@ -614,12 +624,14 @@ class AnalysisServer {
    * otherwise in the first driver, otherwise `null` is returned.
    */
   Future<nd.AnalysisResult> getAnalysisResult(String path) async {
-    nd.AnalysisResult result = priorityFileResults[path];
-    if (result != null) {
-      return result;
+    try {
+      nd.AnalysisDriver driver = getAnalysisDriver(path);
+      return await driver?.getResult(path);
+    } catch (e) {
+      // Ignore the exception.
+      // We don't want to log the same exception again and again.
+      return null;
     }
-    nd.AnalysisDriver driver = getAnalysisDriver(path);
-    return driver?.getResult(path);
   }
 
   CompilationUnitElement getCompilationUnitElement(String file) {
@@ -655,6 +667,19 @@ class AnalysisServer {
     return contextManager.getContextFor(path);
   }
 
+  /**
+   * Return the [nd.AnalysisDriver] for the "innermost" context whose associated
+   * folder is or contains the given path.  ("innermost" refers to the nesting
+   * of contexts, so if there is a context for path /foo and a context for
+   * path /foo/bar, then the innermost context containing /foo/bar/baz.dart is
+   * the context for /foo/bar.)
+   *
+   * If no context contains the given path, `null` is returned.
+   */
+  nd.AnalysisDriver getContainingDriver(String path) {
+    return contextManager.getDriverFor(path);
+  }
+
   /**
    * Return the primary [ContextSourcePair] representing the given [path].
    *
@@ -894,7 +919,7 @@ class AnalysisServer {
    * Return `true` if analysis is complete.
    */
   bool isAnalysisComplete() {
-    return operationQueue.isEmpty;
+    return operationQueue.isEmpty && !analysisDriverScheduler.isAnalyzing;
   }
 
   /**
@@ -1059,7 +1084,7 @@ class AnalysisServer {
    * Schedules analysis of the given context.
    */
   void schedulePerformAnalysisOperation(AnalysisContext context) {
-    _onAnalysisStartedController.add(context);
+    _onAnalysisStartedController.add(true);
     scheduleOperation(new PerformAnalysisOperation(context, false));
   }
 
@@ -1139,10 +1164,24 @@ class AnalysisServer {
   }
 
   /**
-   * Send status notification to the client. The `operation` is the operation
-   * being performed or `null` if analysis is complete.
+   * Send status notification to the client. The state of analysis is given by
+   * the [status] information.
    */
   void sendStatusNotificationNew(nd.AnalysisStatus status) {
+    if (status.isAnalyzing) {
+      _onAnalysisStartedController.add(true);
+    }
+    if (_onAnalysisCompleteCompleter != null && !status.isAnalyzing) {
+      _onAnalysisCompleteCompleter.complete();
+      _onAnalysisCompleteCompleter = null;
+    }
+    // Perform on-idle actions.
+    if (!status.isAnalyzing) {
+      if (generalAnalysisServices
+          .contains(GeneralAnalysisService.ANALYZED_FILES)) {
+        sendAnalysisNotificationAnalyzedFiles(this);
+      }
+    }
     // Only send status when subscribed.
     if (!serverServices.contains(ServerService.STATUS)) {
       return;
@@ -1197,7 +1236,7 @@ class AnalysisServer {
           // The result will be produced by the "results" stream with
           // the fully resolved unit, and processed with sending analysis
           // notifications as it happens after content changes.
-          driver.getResult(file);
+          driver.getResult(file).catchError((exception, stackTrace) {});
         }
       }
       return;
@@ -1245,7 +1284,9 @@ class AnalysisServer {
                 sendAnalysisNotificationHighlights(this, file, dartUnit);
                 break;
               case AnalysisService.OUTLINE:
-                AnalysisContext context = dartUnit.element.context;
+                AnalysisContext context = resolutionMap
+                    .elementDeclaredByCompilationUnit(dartUnit)
+                    .context;
                 LineInfo lineInfo = context.getLineInfo(source);
                 SourceKind kind = context.getKindOf(source);
                 sendAnalysisNotificationOutline(
@@ -1292,10 +1333,6 @@ class AnalysisServer {
    */
   void setPriorityFiles(String requestId, List<String> files) {
     if (options.enableNewAnalysisDriver) {
-      // Flush results for files that are not priority anymore.
-      priorityFiles
-          .difference(files.toSet())
-          .forEach(priorityFileResults.remove);
       priorityFiles.clear();
       priorityFiles.addAll(files);
       // Set priority files in drivers.
@@ -1425,8 +1462,6 @@ class AnalysisServer {
   void updateContent(String id, Map<String, dynamic> changes) {
     if (options.enableNewAnalysisDriver) {
       changes.forEach((file, change) {
-        priorityFileResults.remove(file);
-
         // Prepare the new contents.
         String oldContents = fileContentOverlay[file];
         String newContents;
@@ -1459,6 +1494,11 @@ class AnalysisServer {
         driverMap.values.forEach((driver) {
           driver.changeFile(file);
         });
+
+        // If the file did not exist, and is "overlay only", it still should be
+        // analyzed. Add it to driver to which it should have been added.
+        contextManager.getDriverFor(file)?.addFile(file);
+
         // TODO(scheglov) implement other cases
       });
       return;
@@ -1733,6 +1773,7 @@ class AnalysisServerOptions {
   bool noIndex = false;
   bool useAnalysisHighlight2 = false;
   String fileReadMode = 'as-is';
+  String newAnalysisDriverLog;
 }
 
 /**
@@ -1777,35 +1818,13 @@ class ServerContextManagerCallbacks extends ContextManagerCallbacks {
 
   @override
   nd.AnalysisDriver addAnalysisDriver(Folder folder, AnalysisOptions options) {
-    SourceFactory sourceFactory;
-    AnalysisOptions analysisOptions;
-    {
-      ContextBuilder builder = createContextBuilder(folder, options);
-      AnalysisContext context = builder.buildContext(folder.path);
-      sourceFactory = context.sourceFactory;
-      analysisOptions = context.analysisOptions;
-      context.dispose();
-    }
-    nd.AnalysisDriver analysisDriver = new nd.AnalysisDriver(
-        analysisServer.analysisDriverScheduler,
-        analysisServer._analysisPerformanceLogger,
-        resourceProvider,
-        analysisServer.byteStore,
-        analysisServer.fileContentOverlay,
-        sourceFactory,
-        analysisOptions);
-    analysisDriver.name = folder.shortName;
+    ContextBuilder builder = createContextBuilder(folder, options);
+    nd.AnalysisDriver analysisDriver = builder.buildDriver(folder.path);
     analysisDriver.status.listen((status) {
       // TODO(scheglov) send server status
     });
     analysisDriver.results.listen((result) {
-      if (analysisServer.priorityFiles.contains(result.path) &&
-          result.unit != null) {
-        analysisServer.priorityFileResults[result.path] = result;
-      }
-      _runDelayed(() {
-        new_sendErrorNotification(analysisServer, result);
-      });
+      new_sendErrorNotification(analysisServer, result);
       String path = result.path;
       CompilationUnit unit = result.unit;
       if (unit != null) {
@@ -1821,17 +1840,36 @@ class ServerContextManagerCallbacks extends ContextManagerCallbacks {
             new_sendDartNotificationNavigation(analysisServer, result);
           });
         }
+        if (analysisServer._hasAnalysisServiceSubscription(
+            AnalysisService.OCCURRENCES, path)) {
+          _runDelayed(() {
+            new_sendDartNotificationOccurrences(analysisServer, result);
+          });
+        }
         if (analysisServer._hasAnalysisServiceSubscription(
             AnalysisService.OVERRIDES, path)) {
           _runDelayed(() {
             sendAnalysisNotificationOverrides(analysisServer, path, unit);
           });
         }
+        if (analysisServer._hasAnalysisServiceSubscription(
+            AnalysisService.OUTLINE, path)) {
+          _runDelayed(() {
+            SourceKind sourceKind =
+                unit.directives.any((d) => d is PartOfDirective)
+                    ? SourceKind.PART
+                    : SourceKind.LIBRARY;
+            sendAnalysisNotificationOutline(
+                analysisServer, path, result.lineInfo, sourceKind, unit);
+          });
+        }
       }
       // TODO(scheglov) Implement more notifications.
       // IMPLEMENTED
-      // OCCURRENCES (not used in IDEA)
-      // OUTLINE (not used in IDEA)
+    });
+    analysisDriver.exceptions.listen((nd.ExceptionResult result) {
+      AnalysisEngine.instance.logger
+          .logError('Analysis failed: ${result.path}', result.exception);
     });
     analysisServer.driverMap[folder] = analysisDriver;
     return analysisDriver;
@@ -1880,6 +1918,12 @@ class ServerContextManagerCallbacks extends ContextManagerCallbacks {
     }
   }
 
+  @override
+  void applyFileRemoved(nd.AnalysisDriver driver, String file) {
+    driver.removeFile(file);
+    sendAnalysisNotificationFlushResults(analysisServer, [file]);
+  }
+
   @override
   void computingPackageMap(bool computing) =>
       analysisServer._computingPackageMap(computing);
@@ -1913,6 +1957,10 @@ class ServerContextManagerCallbacks extends ContextManagerCallbacks {
         options: builderOptions);
     builder.fileResolverProvider = analysisServer.fileResolverProvider;
     builder.packageResolverProvider = analysisServer.packageResolverProvider;
+    builder.analysisDriverScheduler = analysisServer.analysisDriverScheduler;
+    builder.performanceLog = analysisServer._analysisPerformanceLogger;
+    builder.byteStore = analysisServer.byteStore;
+    builder.fileContentOverlay = analysisServer.fileContentOverlay;
     return builder;
   }
 
