@@ -19,6 +19,8 @@ import 'package:analysis_server/src/services/completion/dart/contribution_sorter
 import 'package:analysis_server/src/services/completion/dart/optype.dart';
 import 'package:analysis_server/src/services/search/search_engine.dart';
 import 'package:analyzer/dart/ast/ast.dart';
+import 'package:analyzer/dart/ast/standard_ast_factory.dart';
+import 'package:analyzer/dart/ast/standard_resolution_map.dart';
 import 'package:analyzer/dart/ast/token.dart';
 import 'package:analyzer/dart/element/element.dart';
 import 'package:analyzer/dart/element/type.dart';
@@ -178,7 +180,8 @@ class DartCompletionRequestImpl implements DartCompletionRequest {
   @override
   LibraryElement get coreLib {
     if (result != null) {
-      AnalysisContext context = result.unit.element.context;
+      AnalysisContext context =
+          resolutionMap.elementDeclaredByCompilationUnit(result.unit).context;
       _coreLib = context.typeProvider.objectType.element.library;
     } else {
       Source coreUri = sourceFactory.forUri('dart:core');
@@ -189,12 +192,7 @@ class DartCompletionRequestImpl implements DartCompletionRequest {
 
   @override
   bool get includeIdentifiers {
-    opType; // <<< ensure _opType is initialized
-    return !_opType.isPrefixed &&
-        (_opType.includeReturnValueSuggestions ||
-            _opType.includeTypeNameSuggestions ||
-            _opType.includeVoidReturnSuggestions ||
-            _opType.includeConstructorSuggestions);
+    return opType.includeIdentifiers;
   }
 
   @override
@@ -226,7 +224,13 @@ class DartCompletionRequestImpl implements DartCompletionRequest {
   }
 
   @override
-  String get sourceContents => context.getContents(source)?.data;
+  String get sourceContents {
+    if (result != null) {
+      return result.content;
+    } else {
+      return context.getContents(source)?.data;
+    }
+  }
 
   @override
   SourceFactory get sourceFactory {
@@ -305,14 +309,18 @@ class DartCompletionRequestImpl implements DartCompletionRequest {
     if (libElem == null) {
       return null;
     }
-    _resolvedImports = <ImportElement>[];
-    for (ImportElement importElem in libElem.imports) {
-      if (importElem.importedLibrary?.exportNamespace == null) {
-        await _computeAsync(this, importElem.importedLibrary.source,
-            LIBRARY_ELEMENT4, performance, 'resolve imported library');
-        checkAborted();
+    if (result != null) {
+      _resolvedImports = libElem.imports;
+    } else {
+      _resolvedImports = <ImportElement>[];
+      for (ImportElement importElem in libElem.imports) {
+        if (importElem.importedLibrary?.exportNamespace == null) {
+          await _computeAsync(this, importElem.importedLibrary.source,
+              LIBRARY_ELEMENT4, performance, 'resolve imported library');
+          checkAborted();
+        }
+        _resolvedImports.add(importElem);
       }
-      _resolvedImports.add(importElem);
     }
     return _resolvedImports;
   }
@@ -324,7 +332,10 @@ class DartCompletionRequestImpl implements DartCompletionRequest {
       return _resolvedUnits;
     }
     if (result != null) {
-      _resolvedUnits = result.unit.element.library.units;
+      _resolvedUnits = resolutionMap
+          .elementDeclaredByCompilationUnit(result.unit)
+          .library
+          .units;
       return _resolvedUnits;
     }
     LibraryElement libElem = libraryElement;
@@ -395,7 +406,7 @@ class DartCompletionRequestImpl implements DartCompletionRequest {
     if (request.context == null) {
       unit = request.result.unit;
       // TODO(scheglov) support for parts
-      libSource = unit.element.source;
+      libSource = resolutionMap.elementDeclaredByCompilationUnit(unit).source;
     } else {
       Source source = request.source;
       AnalysisContext context = request.context;
@@ -516,7 +527,8 @@ class ReplacementRange {
         }
       }
       if (token is StringToken) {
-        SimpleStringLiteral uri = new SimpleStringLiteral(token, token.lexeme);
+        SimpleStringLiteral uri =
+            astFactory.simpleStringLiteral(token, token.lexeme);
         Keyword keyword = token.previous?.keyword;
         if (keyword == Keyword.IMPORT ||
             keyword == Keyword.EXPORT ||
