@@ -8,6 +8,7 @@ import 'package:analysis_server/src/protocol_server.dart' hide Element;
 import 'package:analysis_server/src/provisional/completion/dart/completion_dart.dart';
 import 'package:analysis_server/src/provisional/completion/dart/completion_target.dart';
 import 'package:analyzer/dart/ast/ast.dart';
+import 'package:analyzer/dart/ast/standard_resolution_map.dart';
 import 'package:analyzer/dart/ast/token.dart';
 import 'package:analyzer/dart/ast/visitor.dart';
 import 'package:analyzer/dart/element/element.dart';
@@ -124,6 +125,17 @@ class OpType {
 
   OpType._();
 
+  /**
+   * Return `true` if free standing identifiers should be suggested
+   */
+  bool get includeIdentifiers {
+    return !isPrefixed &&
+        (includeReturnValueSuggestions ||
+            includeTypeNameSuggestions ||
+            includeVoidReturnSuggestions ||
+            includeConstructorSuggestions);
+  }
+
   /**
    * Indicate whether only type names should be suggested
    */
@@ -567,7 +579,9 @@ class _OpTypeAstVisitor extends GeneralizingAstVisitor {
         if (node.parent is VariableDeclaration) {
           VariableDeclaration varDeclaration =
               node.parent as VariableDeclaration;
-          localTypeAssertion = varDeclaration.element?.type;
+          localTypeAssertion = resolutionMap
+              .elementDeclaredByVariableDeclaration(varDeclaration)
+              ?.type;
         } else if (node.parent is AssignmentExpression) {
           AssignmentExpression assignmentExpression =
               node.parent as AssignmentExpression;
@@ -653,7 +667,7 @@ class _OpTypeAstVisitor extends GeneralizingAstVisitor {
     if (identical(entity, node.expression)) {
       optype.includeReturnValueSuggestions = true;
       optype.returnValueSuggestionsFilter = (DartType dartType, int relevance) {
-        DartType type = node.element?.type;
+        DartType type = resolutionMap.elementForNamedExpression(node)?.type;
         bool isEnum = type != null &&
             type.element is ClassElement &&
             (type.element as ClassElement).isEnum;
@@ -831,9 +845,9 @@ class _OpTypeAstVisitor extends GeneralizingAstVisitor {
 
   @override
   void visitTypeArgumentList(TypeArgumentList node) {
-    NodeList<TypeName> arguments = node.arguments;
-    for (TypeName typeName in arguments) {
-      if (identical(entity, typeName)) {
+    NodeList<TypeAnnotation> arguments = node.arguments;
+    for (TypeAnnotation type in arguments) {
+      if (identical(entity, type)) {
         optype.includeTypeNameSuggestions = true;
         break;
       }
