@@ -16,6 +16,7 @@ import 'package:analysis_server/src/services/refactoring/refactoring_internal.da
 import 'package:analysis_server/src/services/refactoring/rename.dart';
 import 'package:analysis_server/src/services/search/hierarchy.dart';
 import 'package:analysis_server/src/services/search/search_engine.dart';
+import 'package:analysis_server/src/services/search/search_engine_internal.dart';
 import 'package:analyzer/dart/ast/ast.dart';
 import 'package:analyzer/dart/element/element.dart';
 import 'package:analyzer/src/generated/java_core.dart';
@@ -40,7 +41,6 @@ class RenameConstructorRefactoringImpl extends RenameRefactoringImpl {
   @override
   Future<RefactoringStatus> checkFinalConditions() {
     RefactoringStatus result = new RefactoringStatus();
-    _analyzePossibleConflicts(result);
     return new Future.value(result);
   }
 
@@ -48,6 +48,9 @@ class RenameConstructorRefactoringImpl extends RenameRefactoringImpl {
   RefactoringStatus checkNewName() {
     RefactoringStatus result = super.checkNewName();
     result.addStatus(validateConstructorName(newName));
+    if (newName != null) {
+      _analyzePossibleConflicts(result);
+    }
     return result;
   }
 
@@ -70,8 +73,13 @@ class RenameConstructorRefactoringImpl extends RenameRefactoringImpl {
   }
 
   void _analyzePossibleConflicts(RefactoringStatus result) {
-    // check if there are members with "newName" in the same ClassElement
     ClassElement parentClass = element.enclosingElement;
+    // Check if the "newName" is the name of the enclosing class.
+    if (parentClass.name == newName) {
+      result.addError('The constructor should not have the same name '
+          'as the name of the enclosing class.');
+    }
+    // check if there are members with "newName" in the same ClassElement
     for (Element newNameMember in getChildren(parentClass, newName)) {
       String message = format(
           "Class '{0}' already declares {1} with name '{2}'.",
@@ -89,7 +97,7 @@ class RenameConstructorRefactoringImpl extends RenameRefactoringImpl {
     } else {
       sourceRange = rangeStartLength(element.nameEnd, 0);
     }
-    return new SourceReference(new SearchMatch(
+    return new SourceReference(new SearchMatchImpl(
         element.context,
         element.library.source.uri.toString(),
         element.source.uri.toString(),
