@@ -8,16 +8,16 @@ import 'dart:async';
 
 import 'package:analysis_server/plugin/protocol/protocol.dart';
 import 'package:analysis_server/src/constants.dart';
+import 'package:test/test.dart';
 import 'package:test_reflective_loader/test_reflective_loader.dart';
-import 'package:unittest/unittest.dart';
 
 import '../analysis_abstract.dart';
-import '../utils.dart';
 
 main() {
-  initializeTestEnvironment();
-  defineReflectiveTests(AnalysisNotificationHighlightsTest);
-  defineReflectiveTests(HighlightTypeTest);
+  defineReflectiveSuite(() {
+    defineReflectiveTests(AnalysisNotificationHighlightsTest);
+    defineReflectiveTests(HighlightTypeTest);
+  });
 }
 
 @reflectiveTest
@@ -911,6 +911,23 @@ main(int p) {
     assertHasRegion(HighlightRegionType.PARAMETER_REFERENCE, 'p = 42');
   }
 
+  test_PARAMETER_named() async {
+    addTestFile('''
+class C {
+  final int aaa;
+  C({this.aaa, int bbb});
+}
+main() {
+  new C(aaa: 1, bbb: 2);
+}
+''');
+    await prepareHighlights();
+    assertHasRegion(HighlightRegionType.INSTANCE_FIELD_REFERENCE, 'aaa,');
+    assertHasRegion(HighlightRegionType.PARAMETER_DECLARATION, 'bbb}');
+    assertHasRegion(HighlightRegionType.PARAMETER_REFERENCE, 'aaa: 1');
+    assertHasRegion(HighlightRegionType.PARAMETER_REFERENCE, 'bbb: 2');
+  }
+
   test_SETTER_DECLARATION() async {
     addTestFile('''
 set aaa(x) {}
