@@ -8,15 +8,15 @@ import 'dart:async';
 
 import 'package:analysis_server/plugin/protocol/protocol.dart';
 import 'package:analysis_server/src/constants.dart';
+import 'package:test/test.dart';
 import 'package:test_reflective_loader/test_reflective_loader.dart';
-import 'package:unittest/unittest.dart';
 
 import '../analysis_abstract.dart';
-import '../utils.dart';
 
 main() {
-  initializeTestEnvironment();
-  defineReflectiveTests(AnalysisNotificationNavigationTest);
+  defineReflectiveSuite(() {
+    defineReflectiveTests(AnalysisNotificationNavigationTest);
+  });
 }
 
 class AbstractNavigationTest extends AbstractAnalysisTest {
