@@ -2,8 +2,6 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
-library test.integration.analysis.reanalyze;
-
 import 'package:analysis_server/plugin/protocol/protocol.dart';
 import 'package:test/test.dart';
 import 'package:test_reflective_loader/test_reflective_loader.dart';
@@ -12,12 +10,12 @@ import '../integration_tests.dart';
 
 main() {
   defineReflectiveSuite(() {
-    defineReflectiveTests(Test);
+    defineReflectiveTests(ReanalyzeTest);
+    defineReflectiveTests(ReanalyzeTest_Driver);
   });
 }
 
-@reflectiveTest
-class Test extends AbstractAnalysisServerIntegrationTest {
+class AbstractReanalyzeTest extends AbstractAnalysisServerIntegrationTest {
   test_reanalyze() {
     String pathname = sourcePath('test.dart');
     String text = 'main() {}';
@@ -40,3 +38,12 @@ class Test extends AbstractAnalysisServerIntegrationTest {
     });
   }
 }
+
+@reflectiveTest
+class ReanalyzeTest extends AbstractReanalyzeTest {}
+
+@reflectiveTest
+class ReanalyzeTest_Driver extends AbstractReanalyzeTest {
+  @override
+  bool get enableNewAnalysisDriver => true;
+}
