@@ -153,6 +153,11 @@ abstract class AbstractAnalysisServerIntegrationTest
     return completer.future;
   }
 
+  /**
+   * Return `true` if the new analysis driver should be used by these tests.
+   */
+  bool get enableNewAnalysisDriver => false;
+
   /**
    * Print out any messages exchanged with the server.  If some messages have
    * already been exchanged with the server, they are printed out immediately.
@@ -242,6 +247,7 @@ abstract class AbstractAnalysisServerIntegrationTest
       server.start(
           checked: checked,
           diagnosticPort: diagnosticPort,
+          enableNewAnalysisDriver: enableNewAnalysisDriver,
           servicesPort: servicesPort);
 
   /**
@@ -636,6 +642,7 @@ class Server {
       {bool checked: true,
       bool debugServer: false,
       int diagnosticPort,
+      bool enableNewAnalysisDriver: false,
       bool profileServer: false,
       String sdkPath,
       int servicesPort,
@@ -691,6 +698,9 @@ class Server {
     if (useAnalysisHighlight2) {
       arguments.add('--useAnalysisHighlight2');
     }
+    if (enableNewAnalysisDriver) {
+      arguments.add('--enable-new-analysis-driver');
+    }
 //    print('Launching $serverPath');
 //    print('$dartBinary ${arguments.join(' ')}');
     return Process.start(dartBinary, arguments).then((Process process) {
