@@ -4,17 +4,15 @@
 
 library test.integration.search.all;
 
-import 'package:unittest/unittest.dart';
+import 'package:test_reflective_loader/test_reflective_loader.dart';
 
-import '../../utils.dart';
 import 'get_type_hierarchy_test.dart' as get_type_hierarchy_test;
 
 /**
  * Utility for manually running all integration tests.
  */
 main() {
-  initializeTestEnvironment();
-  group('search', () {
+  defineReflectiveSuite(() {
     get_type_hierarchy_test.main();
-  });
+  }, name: 'search');
 }
