@@ -2,8 +2,6 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
-library test.integration.server.status;
-
 import 'dart:async';
 
 import 'package:analysis_server/plugin/protocol/protocol.dart';
@@ -14,12 +12,12 @@ import '../integration_tests.dart';
 
 main() {
   defineReflectiveSuite(() {
-    defineReflectiveTests(Test);
+    defineReflectiveTests(StatusTest);
+    defineReflectiveTests(StatusTest_Driver);
   });
 }
 
-@reflectiveTest
-class Test extends AbstractAnalysisServerIntegrationTest {
+class AbstractStatusTest extends AbstractAnalysisServerIntegrationTest {
   test_status() {
     // After we kick off analysis, we should get one server.status message with
     // analyzing=true, and another server.status message after that with
@@ -52,3 +50,12 @@ main() {
     });
   }
 }
+
+@reflectiveTest
+class StatusTest extends AbstractStatusTest {}
+
+@reflectiveTest
+class StatusTest_Driver extends AbstractStatusTest {
+  @override
+  bool get enableNewAnalysisDriver => true;
+}
