@@ -4,9 +4,8 @@
 
 library test.integration.all;
 
-import 'package:unittest/unittest.dart';
+import 'package:test_reflective_loader/test_reflective_loader.dart';
 
-import '../utils.dart';
 import 'analysis/test_all.dart' as analysis_test_all;
 import 'completion/test_all.dart' as completion_test_all;
 import 'search/test_all.dart' as search_test_all;
@@ -16,11 +15,10 @@ import 'server/test_all.dart' as server_test_all;
  * Utility for manually running all integration tests.
  */
 main() {
-  initializeTestEnvironment();
-  group('analysis_server_integration', () {
+  defineReflectiveSuite(() {
     analysis_test_all.main();
     completion_test_all.main();
     search_test_all.main();
     server_test_all.main();
-  });
+  }, name: 'analysis_server_integration');
 }
