@@ -3,9 +3,8 @@
 // BSD-style license that can be found in the LICENSE file.
 library test.plugin.analysis_contributor;
 
-import 'package:unittest/unittest.dart';
+import 'package:test_reflective_loader/test_reflective_loader.dart';
 
-import '../utils.dart';
 import 'protocol_dart_test.dart' as protocol_dart_test;
 import 'set_analysis_domain_test.dart' as set_analysis_domain_test;
 
@@ -13,9 +12,8 @@ import 'set_analysis_domain_test.dart' as set_analysis_domain_test;
  * Utility for manually running all tests.
  */
 main() {
-  initializeTestEnvironment();
-  group('plugin', () {
+  defineReflectiveSuite(() {
     protocol_dart_test.main();
     set_analysis_domain_test.main();
-  });
+  }, name: 'plugin');
 }
