@@ -15,17 +15,17 @@ import 'package:analyzer/dart/element/type.dart' as engine;
 import 'package:analyzer/error/error.dart' as engine;
 import 'package:analyzer/src/error/codes.dart' as engine;
 import 'package:analyzer/src/generated/source.dart' as engine;
+import 'package:test/test.dart';
 import 'package:test_reflective_loader/test_reflective_loader.dart';
 import 'package:typed_mock/typed_mock.dart';
-import 'package:unittest/unittest.dart';
 
 import 'mocks.dart';
-import 'utils.dart';
 
 main() {
-  initializeTestEnvironment();
-  defineReflectiveTests(AnalysisErrorTest);
-  defineReflectiveTests(EnumTest);
+  defineReflectiveSuite(() {
+    defineReflectiveTests(AnalysisErrorTest);
+    defineReflectiveTests(EnumTest);
+  });
 }
 
 class AnalysisErrorMock extends TypedMock implements engine.AnalysisError {}
