@@ -3,9 +3,8 @@
 // BSD-style license that can be found in the LICENSE file.
 library test.search;
 
-import 'package:unittest/unittest.dart';
+import 'package:test_reflective_loader/test_reflective_loader.dart';
 
-import '../utils.dart';
 import 'element_references_test.dart' as element_references_test;
 import 'member_declarations_test.dart' as member_declarations;
 import 'member_references_test.dart' as member_references_test;
@@ -17,13 +16,12 @@ import 'type_hierarchy_test.dart' as type_hierarchy_test;
  * Utility for manually running all tests.
  */
 main() {
-  initializeTestEnvironment();
-  group('search', () {
+  defineReflectiveSuite(() {
     element_references_test.main();
     member_declarations.main();
     member_references_test.main();
     search_result_test.main();
     top_level_declarations_test.main();
     type_hierarchy_test.main();
-  });
+  }, name: 'search');
 }
