@@ -14,6 +14,7 @@ import 'completion_contributor_util.dart';
 main() {
   defineReflectiveSuite(() {
     defineReflectiveTests(FieldFormalContributorTest);
+    defineReflectiveTests(FieldFormalContributorTest_Driver);
   });
 }
 
@@ -197,3 +198,9 @@ class FieldFormalContributorTest extends DartCompletionContributorTest {
     assertNotSuggested('x');
   }
 }
+
+@reflectiveTest
+class FieldFormalContributorTest_Driver extends FieldFormalContributorTest {
+  @override
+  bool get enableNewAnalysisDriver => true;
+}
