@@ -15,6 +15,7 @@ import 'completion_contributor_util.dart';
 main() {
   defineReflectiveSuite(() {
     defineReflectiveTests(InheritedContributorTest);
+    defineReflectiveTests(InheritedContributorTest_Driver);
   });
 }
 
@@ -617,3 +618,9 @@ class B extends A1 with A2 {
     assertNotSuggested('y2');
   }
 }
+
+@reflectiveTest
+class InheritedContributorTest_Driver extends InheritedContributorTest {
+  @override
+  bool get enableNewAnalysisDriver => true;
+}
