@@ -16,6 +16,7 @@ import 'completion_contributor_util.dart';
 main() {
   defineReflectiveSuite(() {
     defineReflectiveTests(KeywordContributorTest);
+    defineReflectiveTests(KeywordContributorTest_Driver);
   });
 }
 
@@ -1587,3 +1588,9 @@ class A {
     return true;
   }
 }
+
+@reflectiveTest
+class KeywordContributorTest_Driver extends KeywordContributorTest {
+  @override
+  bool get enableNewAnalysisDriver => true;
+}
