@@ -19,6 +19,7 @@ import 'completion_contributor_util.dart';
 main() {
   defineReflectiveSuite(() {
     defineReflectiveTests(LabelContributorTest);
+    defineReflectiveTests(LabelContributorTest_Driver);
   });
 }
 
@@ -324,3 +325,9 @@ void main() {
     assertSuggestLabel('foo');
   }
 }
+
+@reflectiveTest
+class LabelContributorTest_Driver extends LabelContributorTest {
+  @override
+  bool get enableNewAnalysisDriver => true;
+}
