@@ -14,6 +14,7 @@ import 'completion_contributor_util.dart';
 main() {
   defineReflectiveSuite(() {
     defineReflectiveTests(LocalLibraryContributorTest);
+    defineReflectiveTests(LocalLibraryContributorTest_Driver);
   });
 }
 
@@ -306,3 +307,9 @@ class LocalLibraryContributorTest extends DartCompletionContributorTest {
     assertNotSuggested('m');
   }
 }
+
+@reflectiveTest
+class LocalLibraryContributorTest_Driver extends LocalLibraryContributorTest {
+  @override
+  bool get enableNewAnalysisDriver => true;
+}
