@@ -14,6 +14,7 @@ import 'completion_contributor_util.dart';
 main() {
   defineReflectiveSuite(() {
     defineReflectiveTests(StaticMemberContributorTest);
+    defineReflectiveTests(StaticMemberContributorTest_Driver);
   });
 }
 
@@ -287,3 +288,9 @@ void main() {async.Future.^.w()}''');
     assertNotSuggested('==');
   }
 }
+
+@reflectiveTest
+class StaticMemberContributorTest_Driver extends StaticMemberContributorTest {
+  @override
+  bool get enableNewAnalysisDriver => true;
+}
