@@ -14,6 +14,7 @@ import 'completion_contributor_util.dart';
 main() {
   defineReflectiveSuite(() {
     defineReflectiveTests(VariableNameContributorTest);
+    defineReflectiveTests(VariableNameContributorTest_Driver);
   });
 }
 
@@ -244,3 +245,9 @@ class VariableNameContributorTest extends DartCompletionContributorTest {
     assertSuggestName('a');
   }
 }
+
+@reflectiveTest
+class VariableNameContributorTest_Driver extends VariableNameContributorTest {
+  @override
+  bool get enableNewAnalysisDriver => true;
+}
