@@ -4,17 +4,15 @@
 
 library test.services.dependencies;
 
-import 'package:unittest/unittest.dart';
+import 'package:test_reflective_loader/test_reflective_loader.dart';
 
-import '../../utils.dart';
 import 'library_dependencies_test.dart' as library_dependencies;
 import 'reachable_source_collector_test.dart' as reachable_source_collector;
 
 /// Utility for manually running all tests.
 main() {
-  initializeTestEnvironment();
-  group('dependencies', () {
+  defineReflectiveSuite(() {
     library_dependencies.main();
     reachable_source_collector.main();
-  });
+  }, name: 'dependencies');
 }
