@@ -15,13 +15,14 @@ import 'abstract_rename.dart';
 main() {
   defineReflectiveSuite(() {
     defineReflectiveTests(RenameClassMemberTest);
+    defineReflectiveTests(RenameClassMemberTest_Driver);
   });
 }
 
 @reflectiveTest
 class RenameClassMemberTest extends RenameRefactoringTest {
   test_checkFinalConditions_classNameConflict_sameClass() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class NewName {
   void test() {}
 }
@@ -37,7 +38,7 @@ class NewName {
   }
 
   test_checkFinalConditions_classNameConflict_subClass() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class A {
   void test() {} // 1
 }
@@ -56,7 +57,7 @@ class NewName extends A {
   }
 
   test_checkFinalConditions_classNameConflict_superClass() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class NewName {
   void test() {} // 1
 }
@@ -75,7 +76,7 @@ class B extends NewName {
   }
 
   test_checkFinalConditions_hasMember_MethodElement() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class A {
   test() {}
   newName() {} // existing
@@ -92,7 +93,7 @@ class A {
   }
 
   test_checkFinalConditions_OK_dropSuffix() async {
-    indexTestUnit(r'''
+    await indexTestUnit(r'''
 abstract class A {
   void testOld();
 }
@@ -108,7 +109,7 @@ class B implements A {
   }
 
   test_checkFinalConditions_OK_noShadow() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class A {
   int newName;
 }
@@ -129,12 +130,12 @@ class C extends A {
   }
 
   test_checkFinalConditions_publicToPrivate_usedInOtherLibrary() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class A {
   test() {}
 }
 ''');
-    indexUnit(
+    await indexUnit(
         '/lib.dart',
         '''
 library my.lib;
@@ -153,7 +154,7 @@ main(A a) {
   }
 
   test_checkFinalConditions_shadowed_byLocalFunction_inSameClass() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class A {
   test() {}
   main() {
@@ -173,7 +174,7 @@ class A {
   }
 
   test_checkFinalConditions_shadowed_byLocalVariable_inSameClass() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class A {
   test() {}
   main() {
@@ -193,7 +194,7 @@ class A {
   }
 
   test_checkFinalConditions_shadowed_byLocalVariable_inSubClass() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class A {
   test() {}
 }
@@ -215,7 +216,7 @@ class B extends A {
   }
 
   test_checkFinalConditions_shadowed_byLocalVariable_OK_qualifiedReference() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class A {
   test() {}
   main() {
@@ -232,7 +233,7 @@ class A {
   }
 
   test_checkFinalConditions_shadowed_byLocalVariable_OK_renamedNotUsed() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class A {
   test() {}
   main() {
@@ -248,7 +249,7 @@ class A {
   }
 
   test_checkFinalConditions_shadowed_byParameter_inSameClass() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class A {
   test() {}
   main(newName) {
@@ -267,7 +268,7 @@ class A {
   }
 
   test_checkFinalConditions_shadowedBySub_MethodElement() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class A {
   test() {}
 }
@@ -289,7 +290,7 @@ class B extends A {
   }
 
   test_checkFinalConditions_shadowsSuper_FieldElement() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class A {
   int newName; // marker
 }
@@ -312,7 +313,7 @@ class C extends B {
   }
 
   test_checkFinalConditions_shadowsSuper_MethodElement() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class A {
   newName() {} // marker
 }
@@ -335,8 +336,8 @@ class A {
   newName() {} // marker
 }
 ''';
-    indexUnit('/lib.dart', libCode);
-    indexTestUnit('''
+    await indexUnit('/lib.dart', libCode);
+    await indexTestUnit('''
 import 'lib.dart';
 class B extends A {
   test() {}
@@ -353,7 +354,7 @@ class B extends A {
   }
 
   test_checkInitialConditions_inSDK() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 main() {
   'abc'.toUpperCase();
 }
@@ -368,7 +369,7 @@ main() {
   }
 
   test_checkInitialConditions_operator() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class A {
   operator -(other) => this;
 }
@@ -380,8 +381,8 @@ class A {
     assertRefactoringStatus(status, RefactoringProblemSeverity.FATAL);
   }
 
-  test_checkNewName_FieldElement() {
-    indexTestUnit('''
+  test_checkNewName_FieldElement() async {
+    await indexTestUnit('''
 class A {
   int test;
 }
@@ -397,8 +398,8 @@ class A {
     assertRefactoringStatusOK(refactoring.checkNewName());
   }
 
-  test_checkNewName_MethodElement() {
-    indexTestUnit('''
+  test_checkNewName_MethodElement() async {
+    await indexTestUnit('''
 class A {
   test() {}
 }
@@ -425,8 +426,8 @@ class A {
     assertRefactoringStatusOK(refactoring.checkNewName());
   }
 
-  test_createChange_FieldElement() {
-    indexTestUnit('''
+  test_createChange_FieldElement() async {
+    await indexTestUnit('''
 class A {
   int test; // marker
   main() {
@@ -491,8 +492,8 @@ main() {
 ''');
   }
 
-  test_createChange_FieldElement_constructorFieldInitializer() {
-    indexTestUnit('''
+  test_createChange_FieldElement_constructorFieldInitializer() async {
+    await indexTestUnit('''
 class A {
   final test;
   A() : test = 5;
@@ -512,8 +513,8 @@ class A {
 ''');
   }
 
-  test_createChange_FieldElement_fieldFormalParameter() {
-    indexTestUnit('''
+  test_createChange_FieldElement_fieldFormalParameter() async {
+    await indexTestUnit('''
 class A {
   final test;
   A(this.test);
@@ -533,8 +534,8 @@ class A {
 ''');
   }
 
-  test_createChange_FieldElement_fieldFormalParameter_named() {
-    indexTestUnit('''
+  test_createChange_FieldElement_fieldFormalParameter_named() async {
+    await indexTestUnit('''
 class A {
   final test;
   A({this.test});
@@ -560,8 +561,8 @@ main() {
 ''');
   }
 
-  test_createChange_FieldElement_invocation() {
-    indexTestUnit('''
+  test_createChange_FieldElement_invocation() async {
+    await indexTestUnit('''
 typedef F(a);
 class A {
   F test;
@@ -595,8 +596,8 @@ main() {
 ''');
   }
 
-  test_createChange_MethodElement() {
-    indexTestUnit('''
+  test_createChange_MethodElement() async {
+    await indexTestUnit('''
 class A {
   test() {}
 }
@@ -664,7 +665,7 @@ main() {
   }
 
   test_createChange_MethodElement_potential() async {
-    indexTestUnit('''
+    await indexTestUnit('''
 class A {
   test() {}
 }
@@ -695,14 +696,14 @@ main(var a) {
 
   test_createChange_MethodElement_potential_inPubCache() async {
     String pkgLib = '/.pub-cache/lib.dart';
-    indexUnit(
+    await indexUnit(
         pkgLib,
         r'''
 processObj(p) {
   p.test();
 }
 ''');
-    indexTestUnit('''
+    await indexTestUnit('''
 import '$pkgLib';
 class A {
   test() {}
@@ -731,7 +732,7 @@ main(var a) {
   }
 
   test_createChange_MethodElement_potential_private_otherLibrary() async {
-    indexUnit(
+    await indexUnit(
         '/lib.dart',
         '''
 library lib;
@@ -739,7 +740,7 @@ main(p) {
   p._test();
 }
 ''');
-    indexTestUnit('''
+    await indexTestUnit('''
 class A {
   _test() {}
 }
@@ -766,8 +767,8 @@ main(var a) {
     assertNoFileChange('/lib.dart');
   }
 
-  test_createChange_PropertyAccessorElement_getter() {
-    indexTestUnit('''
+  test_createChange_PropertyAccessorElement_getter() async {
+    await indexTestUnit('''
 class A {
   get test {} // marker
   set test(x) {}
@@ -821,8 +822,8 @@ main() {
 ''');
   }
 
-  test_createChange_PropertyAccessorElement_setter() {
-    indexTestUnit('''
+  test_createChange_PropertyAccessorElement_setter() async {
+    await indexTestUnit('''
 class A {
   get test {}
   set test(x) {} // marker
@@ -876,8 +877,8 @@ main() {
 ''');
   }
 
-  test_createChange_TypeParameterElement() {
-    indexTestUnit('''
+  test_createChange_TypeParameterElement() async {
+    await indexTestUnit('''
 class A<Test> {
   Test field;
   List<Test> items;
@@ -900,3 +901,27 @@ class A<NewName> {
 ''');
   }
 }
+
+@reflectiveTest
+class RenameClassMemberTest_Driver extends RenameClassMemberTest {
+  @override
+  bool get enableNewAnalysisDriver => true;
+
+  @failingTest
+  @override
+  test_checkFinalConditions_shadowed_byLocalFunction_inSameClass() {
+    return super.test_checkFinalConditions_shadowed_byLocalFunction_inSameClass();
+  }
+
+  @failingTest
+  @override
+  test_checkFinalConditions_shadowed_byLocalVariable_inSameClass() {
+    return super.test_checkFinalConditions_shadowed_byLocalVariable_inSameClass();
+  }
+
+  @failingTest
+  @override
+  test_checkFinalConditions_shadowed_byLocalVariable_inSubClass() {
+    return super.test_checkFinalConditions_shadowed_byLocalVariable_inSubClass();
+  }
+}
