@@ -7,6 +7,7 @@ library test.services.src.search.all;
 import 'package:test_reflective_loader/test_reflective_loader.dart';
 
 import 'hierarchy_test.dart' as hierarchy_test;
+import 'search_engine2_test.dart' as search_engine2_test;
 import 'search_engine_test.dart' as search_engine_test;
 
 /**
@@ -15,6 +16,7 @@ import 'search_engine_test.dart' as search_engine_test;
 main() {
   defineReflectiveSuite(() {
     hierarchy_test.main();
+    search_engine2_test.main();
     search_engine_test.main();
   }, name: 'search');
 }
