@@ -9,6 +9,7 @@ import 'package:analysis_server/src/provisional/edit/utilities/change_builder_co
 import 'package:analysis_server/src/provisional/edit/utilities/change_builder_dart.dart';
 import 'package:analysis_server/src/utilities/change_builder_dart.dart';
 import 'package:analyzer/dart/ast/ast.dart';
+import 'package:analyzer/dart/ast/standard_resolution_map.dart';
 import 'package:analyzer/dart/element/element.dart';
 import 'package:analyzer/src/generated/source.dart';
 import 'package:test/test.dart';
@@ -26,9 +27,9 @@ main() {
 
 @reflectiveTest
 class DartChangeBuilderImplTest extends AbstractContextTest {
-  void test_createFileEditBuilder() {
+  test_createFileEditBuilder() async {
     Source source = addSource('/test.dart', 'library test;');
-    resolveLibraryUnit(source);
+    await resolveLibraryUnit(source);
     int timeStamp = 54;
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     DartFileEditBuilderImpl fileEditBuilder =
@@ -54,16 +55,17 @@ class DartEditBuilderImplTest extends AbstractContextTest {
     return edits[0];
   }
 
-  void test_writeClassDeclaration_interfaces() {
+  test_writeClassDeclaration_interfaces() async {
     Source source = addSource('/test.dart', 'class A {}');
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     ClassDeclaration declaration = unit.declarations[0];
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
       builder.addInsertion(0, (EditBuilder builder) {
-        (builder as DartEditBuilder)
-            .writeClassDeclaration('C', interfaces: [declaration.element.type]);
+        (builder as DartEditBuilder).writeClassDeclaration('C', interfaces: [
+          resolutionMap.elementDeclaredByClassDeclaration(declaration).type
+        ]);
       });
     });
     SourceEdit edit = getEdit(builder);
@@ -71,9 +73,9 @@ class DartEditBuilderImplTest extends AbstractContextTest {
         edit.replacement, equalsIgnoringWhitespace('class C implements A { }'));
   }
 
-  void test_writeClassDeclaration_isAbstract() {
+  test_writeClassDeclaration_isAbstract() async {
     Source source = addSource('/test.dart', '');
-    resolveLibraryUnit(source);
+    await resolveLibraryUnit(source);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
@@ -86,9 +88,9 @@ class DartEditBuilderImplTest extends AbstractContextTest {
     expect(edit.replacement, equalsIgnoringWhitespace('abstract class C { }'));
   }
 
-  void test_writeClassDeclaration_memberWriter() {
+  test_writeClassDeclaration_memberWriter() async {
     Source source = addSource('/test.dart', '');
-    resolveLibraryUnit(source);
+    await resolveLibraryUnit(source);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
@@ -103,16 +105,17 @@ class DartEditBuilderImplTest extends AbstractContextTest {
     expect(edit.replacement, equalsIgnoringWhitespace('class C { /**/ }'));
   }
 
-  void test_writeClassDeclaration_mixins_noSuperclass() {
+  test_writeClassDeclaration_mixins_noSuperclass() async {
     Source source = addSource('/test.dart', 'class A {}');
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     ClassDeclaration classA = unit.declarations[0];
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
       builder.addInsertion(0, (EditBuilder builder) {
-        (builder as DartEditBuilder)
-            .writeClassDeclaration('C', mixins: [classA.element.type]);
+        (builder as DartEditBuilder).writeClassDeclaration('C', mixins: [
+          resolutionMap.elementDeclaredByClassDeclaration(classA).type
+        ]);
       });
     });
     SourceEdit edit = getEdit(builder);
@@ -120,9 +123,9 @@ class DartEditBuilderImplTest extends AbstractContextTest {
         equalsIgnoringWhitespace('class C extends Object with A { }'));
   }
 
-  void test_writeClassDeclaration_mixins_superclass() {
+  test_writeClassDeclaration_mixins_superclass() async {
     Source source = addSource('/test.dart', 'class A {} class B {}');
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     ClassDeclaration classA = unit.declarations[0];
     ClassDeclaration classB = unit.declarations[1];
 
@@ -130,7 +133,11 @@ class DartEditBuilderImplTest extends AbstractContextTest {
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
       builder.addInsertion(0, (EditBuilder builder) {
         (builder as DartEditBuilder).writeClassDeclaration('C',
-            mixins: [classB.element.type], superclass: classA.element.type);
+            mixins: [
+              resolutionMap.elementDeclaredByClassDeclaration(classB).type
+            ],
+            superclass:
+                resolutionMap.elementDeclaredByClassDeclaration(classA).type);
       });
     });
     SourceEdit edit = getEdit(builder);
@@ -138,9 +145,9 @@ class DartEditBuilderImplTest extends AbstractContextTest {
         equalsIgnoringWhitespace('class C extends A with B { }'));
   }
 
-  void test_writeClassDeclaration_nameGroupName() {
+  test_writeClassDeclaration_nameGroupName() async {
     Source source = addSource('/test.dart', '');
-    resolveLibraryUnit(source);
+    await resolveLibraryUnit(source);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
@@ -160,26 +167,28 @@ class DartEditBuilderImplTest extends AbstractContextTest {
     expect(group.positions, hasLength(1));
   }
 
-  void test_writeClassDeclaration_superclass() {
+  test_writeClassDeclaration_superclass() async {
     Source source = addSource('/test.dart', 'class B {}');
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     ClassDeclaration declaration = unit.declarations[0];
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
       builder.addInsertion(0, (EditBuilder builder) {
-        (builder as DartEditBuilder)
-            .writeClassDeclaration('C', superclass: declaration.element.type);
+        (builder as DartEditBuilder).writeClassDeclaration('C',
+            superclass: resolutionMap
+                .elementDeclaredByClassDeclaration(declaration)
+                .type);
       });
     });
     SourceEdit edit = getEdit(builder);
     expect(edit.replacement, equalsIgnoringWhitespace('class C extends B { }'));
   }
 
-  void test_writeFieldDeclaration_initializerWriter() {
+  test_writeFieldDeclaration_initializerWriter() async {
     String content = 'class A {}';
     Source source = addSource('/test.dart', content);
-    resolveLibraryUnit(source);
+    await resolveLibraryUnit(source);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
@@ -194,10 +203,10 @@ class DartEditBuilderImplTest extends AbstractContextTest {
     expect(edit.replacement, equalsIgnoringWhitespace('var f = e;'));
   }
 
-  void test_writeFieldDeclaration_isConst() {
+  test_writeFieldDeclaration_isConst() async {
     String content = 'class A {}';
     Source source = addSource('/test.dart', content);
-    resolveLibraryUnit(source);
+    await resolveLibraryUnit(source);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
@@ -209,10 +218,10 @@ class DartEditBuilderImplTest extends AbstractContextTest {
     expect(edit.replacement, equalsIgnoringWhitespace('const f;'));
   }
 
-  void test_writeFieldDeclaration_isConst_isFinal() {
+  test_writeFieldDeclaration_isConst_isFinal() async {
     String content = 'class A {}';
     Source source = addSource('/test.dart', content);
-    resolveLibraryUnit(source);
+    await resolveLibraryUnit(source);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
@@ -225,10 +234,10 @@ class DartEditBuilderImplTest extends AbstractContextTest {
     expect(edit.replacement, equalsIgnoringWhitespace('const f;'));
   }
 
-  void test_writeFieldDeclaration_isFinal() {
+  test_writeFieldDeclaration_isFinal() async {
     String content = 'class A {}';
     Source source = addSource('/test.dart', content);
-    resolveLibraryUnit(source);
+    await resolveLibraryUnit(source);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
@@ -240,10 +249,10 @@ class DartEditBuilderImplTest extends AbstractContextTest {
     expect(edit.replacement, equalsIgnoringWhitespace('final f;'));
   }
 
-  void test_writeFieldDeclaration_isStatic() {
+  test_writeFieldDeclaration_isStatic() async {
     String content = 'class A {}';
     Source source = addSource('/test.dart', content);
-    resolveLibraryUnit(source);
+    await resolveLibraryUnit(source);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
@@ -255,10 +264,10 @@ class DartEditBuilderImplTest extends AbstractContextTest {
     expect(edit.replacement, equalsIgnoringWhitespace('static var f;'));
   }
 
-  void test_writeFieldDeclaration_nameGroupName() {
+  test_writeFieldDeclaration_nameGroupName() async {
     String content = 'class A {}';
     Source source = addSource('/test.dart', content);
-    resolveLibraryUnit(source);
+    await resolveLibraryUnit(source);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
@@ -280,17 +289,20 @@ class DartEditBuilderImplTest extends AbstractContextTest {
     expect(position.offset, equals(13));
   }
 
-  void test_writeFieldDeclaration_type_typeGroupName() {
+  test_writeFieldDeclaration_type_typeGroupName() async {
     String content = 'class A {} class B {}';
     Source source = addSource('/test.dart', content);
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     ClassDeclaration declaration = unit.declarations[0];
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
       builder.addInsertion(content.length - 1, (EditBuilder builder) {
         (builder as DartEditBuilder).writeFieldDeclaration('f',
-            type: declaration.element.type, typeGroupName: 'type');
+            type: resolutionMap
+                .elementDeclaredByClassDeclaration(declaration)
+                .type,
+            typeGroupName: 'type');
       });
     });
     SourceEdit edit = getEdit(builder);
@@ -306,10 +318,10 @@ class DartEditBuilderImplTest extends AbstractContextTest {
     expect(position.offset, equals(20));
   }
 
-  void test_writeGetterDeclaration_bodyWriter() {
+  test_writeGetterDeclaration_bodyWriter() async {
     String content = 'class A {}';
     Source source = addSource('/test.dart', content);
-    resolveLibraryUnit(source);
+    await resolveLibraryUnit(source);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
@@ -324,10 +336,10 @@ class DartEditBuilderImplTest extends AbstractContextTest {
     expect(edit.replacement, equalsIgnoringWhitespace('get g {}'));
   }
 
-  void test_writeGetterDeclaration_isStatic() {
+  test_writeGetterDeclaration_isStatic() async {
     String content = 'class A {}';
     Source source = addSource('/test.dart', content);
-    resolveLibraryUnit(source);
+    await resolveLibraryUnit(source);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
@@ -340,10 +352,10 @@ class DartEditBuilderImplTest extends AbstractContextTest {
     expect(edit.replacement, equalsIgnoringWhitespace('static get g => null;'));
   }
 
-  void test_writeGetterDeclaration_nameGroupName() {
+  test_writeGetterDeclaration_nameGroupName() async {
     String content = 'class A {}';
     Source source = addSource('/test.dart', content);
-    resolveLibraryUnit(source);
+    await resolveLibraryUnit(source);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
@@ -365,17 +377,19 @@ class DartEditBuilderImplTest extends AbstractContextTest {
     expect(position.offset, equals(13));
   }
 
-  void test_writeGetterDeclaration_returnType() {
+  test_writeGetterDeclaration_returnType() async {
     String content = 'class A {} class B {}';
     Source source = addSource('/test.dart', content);
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     ClassDeclaration classA = unit.declarations[0];
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
       builder.addInsertion(content.length - 1, (EditBuilder builder) {
         (builder as DartEditBuilder).writeGetterDeclaration('g',
-            returnType: classA.element.type, returnTypeGroupName: 'returnType');
+            returnType:
+                resolutionMap.elementDeclaredByClassDeclaration(classA).type,
+            returnTypeGroupName: 'returnType');
       });
     });
     SourceEdit edit = getEdit(builder);
@@ -391,7 +405,7 @@ class DartEditBuilderImplTest extends AbstractContextTest {
     expect(position.offset, equals(20));
   }
 
-  void test_writeOverrideOfInheritedMember() {
+  test_writeOverrideOfInheritedMember() async {
     String content = '''
 class A {
   A add(A a) => null;
@@ -399,14 +413,16 @@ class A {
 class B extends A {
 }''';
     Source source = addSource('/test.dart', content);
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     ClassDeclaration declaration = unit.declarations[0];
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
       builder.addInsertion(content.length - 1, (EditBuilder builder) {
-        (builder as DartEditBuilder)
-            .writeOverrideOfInheritedMember(declaration.element.methods[0]);
+        (builder as DartEditBuilder).writeOverrideOfInheritedMember(
+            resolutionMap
+                .elementDeclaredByClassDeclaration(declaration)
+                .methods[0]);
       });
     });
     SourceEdit edit = getEdit(builder);
@@ -418,14 +434,14 @@ A add(A a) {
 }'''));
   }
 
-  void test_writeParameters_named() {
+  test_writeParameters_named() async {
     String content = 'f(int i, {String s}) {}';
     Source source = addSource('/test.dart', content);
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     FunctionDeclaration f = unit.declarations[0];
     FormalParameterList parameters = f.functionExpression.parameters;
     Iterable<ParameterElement> elements = parameters.parameters
-        .map((FormalParameter parameter) => parameter.element);
+        .map(resolutionMap.elementDeclaredByFormalParameter);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
@@ -437,14 +453,14 @@ A add(A a) {
     expect(edit.replacement, equalsIgnoringWhitespace('(int i, {String s})'));
   }
 
-  void test_writeParameters_positional() {
+  test_writeParameters_positional() async {
     String content = 'f(int i, [String s]) {}';
     Source source = addSource('/test.dart', content);
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     FunctionDeclaration f = unit.declarations[0];
     FormalParameterList parameters = f.functionExpression.parameters;
     Iterable<ParameterElement> elements = parameters.parameters
-        .map((FormalParameter parameter) => parameter.element);
+        .map(resolutionMap.elementDeclaredByFormalParameter);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
@@ -456,14 +472,14 @@ A add(A a) {
     expect(edit.replacement, equalsIgnoringWhitespace('(int i, [String s])'));
   }
 
-  void test_writeParameters_required() {
+  test_writeParameters_required() async {
     String content = 'f(int i, String s) {}';
     Source source = addSource('/test.dart', content);
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     FunctionDeclaration f = unit.declarations[0];
     FormalParameterList parameters = f.functionExpression.parameters;
     Iterable<ParameterElement> elements = parameters.parameters
-        .map((FormalParameter parameter) => parameter.element);
+        .map(resolutionMap.elementDeclaredByFormalParameter);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
@@ -475,13 +491,13 @@ A add(A a) {
     expect(edit.replacement, equalsIgnoringWhitespace('(int i, String s)'));
   }
 
-  void test_writeParametersMatchingArguments_named() {
+  test_writeParametersMatchingArguments_named() async {
     String content = '''
 f(int i, String s) {
   g(s, index: i);
 }''';
     Source source = addSource('/test.dart', content);
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     FunctionDeclaration f = unit.declarations[0];
     BlockFunctionBody body = f.functionExpression.body;
     ExpressionStatement statement = body.block.statements[0];
@@ -499,13 +515,13 @@ f(int i, String s) {
         edit.replacement, equalsIgnoringWhitespace('(String s, [int index])'));
   }
 
-  void test_writeParametersMatchingArguments_required() {
+  test_writeParametersMatchingArguments_required() async {
     String content = '''
 f(int i, String s) {
   g(s, i);
 }''';
     Source source = addSource('/test.dart', content);
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     FunctionDeclaration f = unit.declarations[0];
     BlockFunctionBody body = f.functionExpression.body;
     ExpressionStatement statement = body.block.statements[0];
@@ -522,68 +538,76 @@ f(int i, String s) {
     expect(edit.replacement, equalsIgnoringWhitespace('(String s, int i)'));
   }
 
-  void test_writeParameterSource() {
+  test_writeParameterSource() async {
     String content = 'class A {}';
     Source source = addSource('/test.dart', content);
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     ClassDeclaration classA = unit.declarations[0];
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
       builder.addInsertion(content.length - 1, (EditBuilder builder) {
-        (builder as DartEditBuilder)
-            .writeParameterSource(classA.element.type, 'a');
+        (builder as DartEditBuilder).writeParameterSource(
+            resolutionMap.elementDeclaredByClassDeclaration(classA).type, 'a');
       });
     });
     SourceEdit edit = getEdit(builder);
     expect(edit.replacement, equalsIgnoringWhitespace('A a'));
   }
 
-  void test_writeType_dymanic() {
+  test_writeType_dynamic() async {
     String content = 'class A {}';
     Source source = addSource('/test.dart', content);
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
       builder.addInsertion(content.length - 1, (EditBuilder builder) {
-        (builder as DartEditBuilder)
-            .writeType(unit.element.context.typeProvider.dynamicType);
+        (builder as DartEditBuilder).writeType(resolutionMap
+            .elementDeclaredByCompilationUnit(unit)
+            .context
+            .typeProvider
+            .dynamicType);
       });
     });
     SourceEdit edit = getEdit(builder);
     expect(edit.replacement, equalsIgnoringWhitespace(''));
   }
 
-  void test_writeType_genericType() {
+  test_writeType_genericType() async {
     String content = 'class A {} class B<E> {}';
     Source source = addSource('/test.dart', content);
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     ClassDeclaration classA = unit.declarations[0];
     ClassDeclaration classB = unit.declarations[1];
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
       builder.addInsertion(content.length - 1, (EditBuilder builder) {
-        (builder as DartEditBuilder)
-            .writeType(classB.element.type.instantiate([classA.element.type]));
+        (builder as DartEditBuilder).writeType(resolutionMap
+            .elementDeclaredByClassDeclaration(classB)
+            .type
+            .instantiate([
+          resolutionMap.elementDeclaredByClassDeclaration(classA).type
+        ]));
       });
     });
     SourceEdit edit = getEdit(builder);
     expect(edit.replacement, equalsIgnoringWhitespace('B<A>'));
   }
 
-  void test_writeType_groupName() {
+  test_writeType_groupName() async {
     String content = 'class A {} class B extends A {} class C extends B {}';
     Source source = addSource('/test.dart', content);
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     ClassDeclaration classC = unit.declarations[2];
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
       builder.addInsertion(content.length - 1, (EditBuilder builder) {
-        (builder as DartEditBuilder)
-            .writeType(classC.element.type, groupName: 'type');
+        (builder as DartEditBuilder).writeType(
+            resolutionMap.elementDeclaredByClassDeclaration(classC).type,
+            groupName: 'type');
       });
     });
     SourceEdit edit = getEdit(builder);
@@ -596,17 +620,19 @@ f(int i, String s) {
     expect(group, isNotNull);
   }
 
-  void test_writeType_groupName_addSupertypeProposals() {
+  test_writeType_groupName_addSupertypeProposals() async {
     String content = 'class A {} class B extends A {} class C extends B {}';
     Source source = addSource('/test.dart', content);
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     ClassDeclaration classC = unit.declarations[2];
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
       builder.addInsertion(content.length - 1, (EditBuilder builder) {
-        (builder as DartEditBuilder).writeType(classC.element.type,
-            addSupertypeProposals: true, groupName: 'type');
+        (builder as DartEditBuilder).writeType(
+            resolutionMap.elementDeclaredByClassDeclaration(classC).type,
+            addSupertypeProposals: true,
+            groupName: 'type');
       });
     });
     SourceEdit edit = getEdit(builder);
@@ -629,10 +655,10 @@ f(int i, String s) {
     expect(values, contains('C'));
   }
 
-  void test_writeType_null() {
+  test_writeType_null() async {
     String content = 'class A {}';
     Source source = addSource('/test.dart', content);
-    resolveLibraryUnit(source);
+    await resolveLibraryUnit(source);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
@@ -644,16 +670,20 @@ f(int i, String s) {
     expect(edit.replacement, equalsIgnoringWhitespace(''));
   }
 
-  void test_writeType_required_dymanic() {
+  test_writeType_required_dynamic() async {
     String content = 'class A {}';
     Source source = addSource('/test.dart', content);
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
       builder.addInsertion(content.length - 1, (EditBuilder builder) {
         (builder as DartEditBuilder).writeType(
-            unit.element.context.typeProvider.dynamicType,
+            resolutionMap
+                .elementDeclaredByCompilationUnit(unit)
+                .context
+                .typeProvider
+                .dynamicType,
             required: true);
       });
     });
@@ -661,27 +691,28 @@ f(int i, String s) {
     expect(edit.replacement, equalsIgnoringWhitespace('var'));
   }
 
-  void test_writeType_required_notNull() {
+  test_writeType_required_notNull() async {
     String content = 'class A {}';
     Source source = addSource('/test.dart', content);
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     ClassDeclaration classA = unit.declarations[0];
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
       builder.addInsertion(content.length - 1, (EditBuilder builder) {
-        (builder as DartEditBuilder)
-            .writeType(classA.element.type, required: true);
+        (builder as DartEditBuilder).writeType(
+            resolutionMap.elementDeclaredByClassDeclaration(classA).type,
+            required: true);
       });
     });
     SourceEdit edit = getEdit(builder);
     expect(edit.replacement, equalsIgnoringWhitespace('A'));
   }
 
-  void test_writeType_required_null() {
+  test_writeType_required_null() async {
     String content = 'class A {}';
     Source source = addSource('/test.dart', content);
-    resolveLibraryUnit(source);
+    await resolveLibraryUnit(source);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
@@ -693,26 +724,27 @@ f(int i, String s) {
     expect(edit.replacement, equalsIgnoringWhitespace('var'));
   }
 
-  void test_writeType_simpleType() {
+  test_writeType_simpleType() async {
     String content = 'class A {}';
     Source source = addSource('/test.dart', content);
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     ClassDeclaration classA = unit.declarations[0];
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
       builder.addInsertion(content.length - 1, (EditBuilder builder) {
-        (builder as DartEditBuilder).writeType(classA.element.type);
+        (builder as DartEditBuilder).writeType(
+            resolutionMap.elementDeclaredByClassDeclaration(classA).type);
       });
     });
     SourceEdit edit = getEdit(builder);
     expect(edit.replacement, equalsIgnoringWhitespace('A'));
   }
 
-  void test_writeTypes_empty() {
+  test_writeTypes_empty() async {
     String content = 'class A {}';
     Source source = addSource('/test.dart', content);
-    resolveLibraryUnit(source);
+    await resolveLibraryUnit(source);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
@@ -724,28 +756,30 @@ f(int i, String s) {
     expect(edit.replacement, isEmpty);
   }
 
-  void test_writeTypes_noPrefix() {
+  test_writeTypes_noPrefix() async {
     String content = 'class A {} class B {}';
     Source source = addSource('/test.dart', content);
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     ClassDeclaration classA = unit.declarations[0];
     ClassDeclaration classB = unit.declarations[1];
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
       builder.addInsertion(content.length - 1, (EditBuilder builder) {
-        (builder as DartEditBuilderImpl)
-            .writeTypes([classA.element.type, classB.element.type]);
+        (builder as DartEditBuilderImpl).writeTypes([
+          resolutionMap.elementDeclaredByClassDeclaration(classA).type,
+          resolutionMap.elementDeclaredByClassDeclaration(classB).type
+        ]);
       });
     });
     SourceEdit edit = getEdit(builder);
     expect(edit.replacement, equalsIgnoringWhitespace('A, B'));
   }
 
-  void test_writeTypes_null() {
+  test_writeTypes_null() async {
     String content = 'class A {}';
     Source source = addSource('/test.dart', content);
-    resolveLibraryUnit(source);
+    await resolveLibraryUnit(source);
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
@@ -757,19 +791,20 @@ f(int i, String s) {
     expect(edit.replacement, isEmpty);
   }
 
-  void test_writeTypes_prefix() {
+  test_writeTypes_prefix() async {
     String content = 'class A {} class B {}';
     Source source = addSource('/test.dart', content);
-    CompilationUnit unit = resolveLibraryUnit(source);
+    CompilationUnit unit = await resolveLibraryUnit(source);
     ClassDeclaration classA = unit.declarations[0];
     ClassDeclaration classB = unit.declarations[1];
 
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, 1, (FileEditBuilder builder) {
       builder.addInsertion(content.length - 1, (EditBuilder builder) {
-        (builder as DartEditBuilderImpl).writeTypes(
-            [classA.element.type, classB.element.type],
-            prefix: 'implements ');
+        (builder as DartEditBuilderImpl).writeTypes([
+          resolutionMap.elementDeclaredByClassDeclaration(classA).type,
+          resolutionMap.elementDeclaredByClassDeclaration(classB).type
+        ], prefix: 'implements ');
       });
     });
     SourceEdit edit = getEdit(builder);
@@ -779,9 +814,9 @@ f(int i, String s) {
 
 @reflectiveTest
 class DartFileEditBuilderImplTest extends AbstractContextTest {
-  void test_createEditBuilder() {
+  test_createEditBuilder() async {
     Source source = addSource('/test.dart', 'library test;');
-    resolveLibraryUnit(source);
+    await resolveLibraryUnit(source);
     int timeStamp = 65;
     DartChangeBuilderImpl builder = new DartChangeBuilderImpl(context);
     builder.addFileEdit(source, timeStamp, (FileEditBuilder builder) {
