@@ -12,8 +12,8 @@ import 'dart:collection';
 import 'package:analyzer/dart/constant/value.dart';
 import 'package:analyzer/dart/element/element.dart';
 import 'package:analyzer/dart/element/type.dart';
-import 'package:analyzer/src/generated/error.dart';
-import 'package:analyzer/src/generated/java_core.dart';
+import 'package:analyzer/error/error.dart';
+import 'package:analyzer/src/error/codes.dart';
 import 'package:analyzer/src/generated/resolver.dart' show TypeProvider;
 import 'package:analyzer/src/generated/utilities_general.dart';
 
@@ -144,9 +144,6 @@ class DartObjectImpl implements DartObject {
    */
   static const List<DartObjectImpl> EMPTY_LIST = const <DartObjectImpl>[];
 
-  /**
-   * The run-time type of this object.
-   */
   @override
   final ParameterizedType type;
 
@@ -163,7 +160,7 @@ class DartObjectImpl implements DartObject {
   /**
    * Create an object to represent an unknown value.
    */
-  factory DartObjectImpl.validWithUnknownValue(InterfaceType type) {
+  factory DartObjectImpl.validWithUnknownValue(ParameterizedType type) {
     if (type.element.library.isDartCore) {
       String typeName = type.name;
       if (typeName == "bool") {
@@ -240,7 +237,7 @@ class DartObjectImpl implements DartObject {
       return new DartObjectImpl(typeProvider.stringType, result);
     }
     // We should never get here.
-    throw new IllegalStateException("add returned a ${result.runtimeType}");
+    throw new StateError("add returned a ${result.runtimeType}");
   }
 
   /**
@@ -339,7 +336,7 @@ class DartObjectImpl implements DartObject {
       return new DartObjectImpl(typeProvider.numType, result);
     }
     // We should never get here.
-    throw new IllegalStateException("divide returned a ${result.runtimeType}");
+    throw new StateError("divide returned a ${result.runtimeType}");
   }
 
   /**
@@ -508,7 +505,7 @@ class DartObjectImpl implements DartObject {
       return new DartObjectImpl(typeProvider.numType, result);
     }
     // We should never get here.
-    throw new IllegalStateException("minus returned a ${result.runtimeType}");
+    throw new StateError("minus returned a ${result.runtimeType}");
   }
 
   /**
@@ -528,7 +525,7 @@ class DartObjectImpl implements DartObject {
       return new DartObjectImpl(typeProvider.numType, result);
     }
     // We should never get here.
-    throw new IllegalStateException("negated returned a ${result.runtimeType}");
+    throw new StateError("negated returned a ${result.runtimeType}");
   }
 
   /**
@@ -589,8 +586,7 @@ class DartObjectImpl implements DartObject {
       return new DartObjectImpl(typeProvider.numType, result);
     }
     // We should never get here.
-    throw new IllegalStateException(
-        "remainder returned a ${result.runtimeType}");
+    throw new StateError("remainder returned a ${result.runtimeType}");
   }
 
   /**
@@ -647,7 +643,7 @@ class DartObjectImpl implements DartObject {
       return new DartObjectImpl(typeProvider.numType, result);
     }
     // We should never get here.
-    throw new IllegalStateException("times returned a ${result.runtimeType}");
+    throw new StateError("times returned a ${result.runtimeType}");
   }
 
   @override
@@ -1231,9 +1227,9 @@ class DynamicState extends InstanceState {
 }
 
 /**
- * A run-time exception that would be thrown during the evaluation of Dart code.
+ * Exception that would be thrown during the evaluation of Dart code.
  */
-class EvaluationException extends JavaException {
+class EvaluationException {
   /**
    * The error code associated with the exception.
    */
