@@ -60,7 +60,8 @@ class ConstructorMember extends ExecutableMember implements ConstructorElement {
       from(baseElement.redirectedConstructor, definingType);
 
   @override
-  accept(ElementVisitor visitor) => visitor.visitConstructorElement(this);
+  /*=T*/ accept/*<T>*/(ElementVisitor<dynamic/*=T*/ > visitor) =>
+      visitor.visitConstructorElement(this);
 
   @override
   ConstructorDeclaration computeNode() => baseElement.computeNode();
@@ -243,7 +244,7 @@ class FieldFormalParameterMember extends ParameterMember
   }
 
   @override
-  accept(ElementVisitor visitor) =>
+  /*=T*/ accept/*<T>*/(ElementVisitor<dynamic/*=T*/ > visitor) =>
       visitor.visitFieldFormalParameterElement(this);
 }
 
@@ -283,7 +284,8 @@ class FieldMember extends VariableMember implements FieldElement {
       PropertyAccessorMember.from(baseElement.setter, definingType);
 
   @override
-  accept(ElementVisitor visitor) => visitor.visitFieldElement(this);
+  /*=T*/ accept/*<T>*/(ElementVisitor<dynamic/*=T*/ > visitor) =>
+      visitor.visitFieldElement(this);
 
   @override
   VariableDeclaration computeNode() => baseElement.computeNode();
@@ -374,7 +376,8 @@ class FunctionMember extends ExecutableMember implements FunctionElement {
   SourceRange get visibleRange => baseElement.visibleRange;
 
   @override
-  accept(ElementVisitor visitor) => visitor.visitFunctionElement(this);
+  /*=T*/ accept/*<T>*/(ElementVisitor<dynamic/*=T*/ > visitor) =>
+      visitor.visitFunctionElement(this);
 
   @override
   FunctionDeclaration computeNode() => baseElement.computeNode();
@@ -593,11 +596,16 @@ class MethodMember extends ExecutableMember implements MethodElement {
   ClassElement get enclosingElement => baseElement.enclosingElement;
 
   @override
-  accept(ElementVisitor visitor) => visitor.visitMethodElement(this);
+  /*=T*/ accept/*<T>*/(ElementVisitor<dynamic/*=T*/ > visitor) =>
+      visitor.visitMethodElement(this);
 
   @override
   MethodDeclaration computeNode() => baseElement.computeNode();
 
+  @override
+  FunctionType getReifiedType(DartType objectType) =>
+      substituteFor(baseElement.getReifiedType(objectType));
+
   @override
   String toString() {
     MethodElement baseElement = this.baseElement;
@@ -696,7 +704,8 @@ class ParameterMember extends VariableMember
   SourceRange get visibleRange => baseElement.visibleRange;
 
   @override
-  accept(ElementVisitor visitor) => visitor.visitParameterElement(this);
+  /*=T*/ accept/*<T>*/(ElementVisitor<dynamic/*=T*/ > visitor) =>
+      visitor.visitParameterElement(this);
 
   @override
   FormalParameter computeNode() => baseElement.computeNode();
@@ -792,7 +801,8 @@ class PropertyAccessorMember extends ExecutableMember
   }
 
   @override
-  accept(ElementVisitor visitor) => visitor.visitPropertyAccessorElement(this);
+  /*=T*/ accept/*<T>*/(ElementVisitor<dynamic/*=T*/ > visitor) =>
+      visitor.visitPropertyAccessorElement(this);
 
   @override
   String toString() {
@@ -898,13 +908,11 @@ class PropertyAccessorMember extends ExecutableMember
  * [FunctionType.returnType], and [ParameterMember].
  */
 class TypeParameterMember extends Member implements TypeParameterElement {
-  @override
-  final DartType bound;
-
+  DartType _bound;
   DartType _type;
 
   TypeParameterMember(
-      TypeParameterElement baseElement, DartType definingType, this.bound)
+      TypeParameterElement baseElement, DartType definingType, this._bound)
       : super(baseElement, definingType) {
     _type = new TypeParameterTypeImpl(this);
   }
@@ -913,6 +921,9 @@ class TypeParameterMember extends Member implements TypeParameterElement {
   TypeParameterElement get baseElement =>
       super.baseElement as TypeParameterElement;
 
+  @override
+  DartType get bound => _bound;
+
   @override
   Element get enclosingElement => baseElement.enclosingElement;
 
@@ -923,7 +934,8 @@ class TypeParameterMember extends Member implements TypeParameterElement {
   TypeParameterType get type => _type;
 
   @override
-  accept(ElementVisitor visitor) => visitor.visitTypeParameterElement(this);
+  /*=T*/ accept/*<T>*/(ElementVisitor<dynamic/*=T*/ > visitor) =>
+      visitor.visitTypeParameterElement(this);
 
   /**
    * If the given [parameter]'s type is different when any type parameters from
@@ -932,19 +944,41 @@ class TypeParameterMember extends Member implements TypeParameterElement {
    * the given parameter. Return the member that was created, or the base
    * parameter if no member was created.
    */
-  static TypeParameterElement from(
-      TypeParameterElement parameter, ParameterizedType definingType) {
-    if (parameter?.bound == null || definingType.typeArguments.isEmpty) {
-      return parameter;
-    }
-
-    DartType bound = parameter.bound;
+  static List<TypeParameterElement> from(
+      List<TypeParameterElement> formals, FunctionType definingType) {
     List<DartType> argumentTypes = definingType.typeArguments;
+    if (argumentTypes.isEmpty) {
+      return formals;
+    }
     List<DartType> parameterTypes =
         TypeParameterTypeImpl.getTypes(definingType.typeParameters);
-    DartType substitutedBound =
-        bound.substitute2(argumentTypes, parameterTypes);
-    return new TypeParameterMember(parameter, definingType, substitutedBound);
+
+    // Create type formals with specialized bounds.
+    // For example `<U extends T>` where T comes from an outer scope.
+    var results = formals.toList(growable: false);
+    for (int i = 0; i < results.length; i++) {
+      var formal = results[i];
+      DartType bound = formal?.bound;
+      if (bound != null) {
+        // substitute type arguments from the function.
+        bound = bound.substitute2(argumentTypes, parameterTypes);
+        results[i] = new TypeParameterMember(formal, definingType, bound);
+      }
+    }
+    List<TypeParameterType> formalTypes =
+        TypeParameterTypeImpl.getTypes(formals);
+    for (var formal in results) {
+      if (formal is TypeParameterMember) {
+        // Recursive bounds are allowed too, so make sure these are updated
+        // to refer to any new TypeParameterMember we just made, rather than
+        // the original type parameter
+        // TODO(jmesserly): this is required so substituting for the
+        // type formal will work. Investigate if there's a better solution.
+        formal._bound = formal.bound
+            .substitute2(TypeParameterTypeImpl.getTypes(results), formalTypes);
+      }
+    }
+    return results;
   }
 }
 
