@@ -1347,7 +1347,12 @@ enum UnlinkedConstructorInitializerKind {
   /**
    * Invocation of a superclass' constructor.
    */
-  superInvocation
+  superInvocation,
+
+  /**
+   * Invocation of `assert`.
+   */
+  assertInvocation
 }
 
 /**
@@ -2347,6 +2352,42 @@ enum UnlinkedExprOperation {
    * completion.  Then push the awaited value onto the stack.
    */
   await,
+
+  /**
+   * Push an abstract value onto the stack. Abstract values mark the presence of
+   * a value, but whose details are not included.
+   *
+   * This is not used by the summary generators today, but it will be used to
+   * experiment with prunning the initializer expression tree, so only
+   * information that is necessary gets included in the output summary file.
+   */
+  pushUntypedAbstract,
+
+  /**
+   * Get the next type reference from [UnlinkedExpr.references] and push an
+   * abstract value onto the stack that has that type.
+   *
+   * Like [pushUntypedAbstract], this is also not used by the summary generators
+   * today. The plan is to experiment with prunning the initializer expression
+   * tree, and include just enough type information to perform strong-mode type
+   * inference, but not all the details of how this type was obtained.
+   */
+  pushTypedAbstract,
+
+  /**
+   * Push an error onto the stack.
+   *
+   * Like [pushUntypedAbstract], this is not used by summary generators today.
+   * This will be used to experiment with prunning the const expression tree. If
+   * a constant has an error, we can omit the subexpression containing the error
+   * and only include a marker that an error was detected.
+   */
+  pushError,
+
+  /**
+   * Push `this` expression onto the stack.
+   */
+  pushThis,
 }
 
 /**
@@ -2520,6 +2561,18 @@ abstract class UnlinkedParam extends base.SummaryClass {
   @Id(12)
   UnlinkedExecutable get initializer;
 
+  /**
+   * Indicates whether this parameter is explicitly marked as being covariant.
+   */
+  @Id(15)
+  bool get isExplicitlyCovariant;
+
+  /**
+   * Indicates whether the parameter is declared using the `final` keyword.
+   */
+  @Id(16)
+  bool get isFinal;
+
   /**
    * Indicates whether this is a function-typed parameter.
    */
@@ -3018,6 +3071,13 @@ abstract class UnlinkedVariable extends base.SummaryClass {
   @Id(6)
   bool get isConst;
 
+  /**
+   * Indicates whether this variable is declared using the `covariant` keyword.
+   * This should be false for everything except instance fields.
+   */
+  @Id(14)
+  bool get isCovariant;
+
   /**
    * Indicates whether the variable is declared using the `final` keyword.
    */
