@@ -4,19 +4,17 @@
 
 library analyzer.test.src.context.test_all;
 
-import 'package:unittest/unittest.dart';
+import 'package:test_reflective_loader/test_reflective_loader.dart';
 
-import '../../utils.dart';
 import 'builder_test.dart' as builder_test;
 import 'cache_test.dart' as cache_test;
 import 'context_test.dart' as context_test;
 
 /// Utility for manually running all tests.
 main() {
-  initializeTestEnvironment();
-  group('context tests', () {
+  defineReflectiveSuite(() {
     builder_test.main();
     cache_test.main();
     context_test.main();
-  });
+  }, name: 'context');
 }
