@@ -7,7 +7,6 @@ library test.src.serialization.test_all;
 import 'package:test_reflective_loader/test_reflective_loader.dart';
 
 import 'api_signature_test.dart' as api_signature_test;
-import 'bazel_summary_test.dart' as bazel_summary_test;
 import 'flat_buffers_test.dart' as flat_buffers_test;
 import 'in_summary_source_test.dart' as in_summary_source_test;
 import 'linker_test.dart' as linker_test;
@@ -23,7 +22,6 @@ import 'summarize_ast_test.dart' as summarize_ast_test;
 main() {
   defineReflectiveSuite(() {
     api_signature_test.main();
-    bazel_summary_test.main();
     flat_buffers_test.main();
     in_summary_source_test.main();
     linker_test.main();
