@@ -14,12 +14,12 @@ _invokeErrorHandler(Function errorHandler,
   }
 }
 
-Function _registerErrorHandler/*<R>*/(Function errorHandler, Zone zone) {
+Function _registerErrorHandler<R>(Function errorHandler, Zone zone) {
   if (errorHandler is ZoneBinaryCallback) {
-    return zone.registerBinaryCallback/*<R, dynamic, StackTrace>*/(
+    return zone.registerBinaryCallback<R, dynamic, StackTrace>(
         errorHandler as dynamic/*=ZoneBinaryCallback<R, dynamic, StackTrace>*/);
   } else {
-    return zone.registerUnaryCallback/*<R, dynamic>*/(
+    return zone.registerUnaryCallback<R, dynamic>(
         errorHandler as dynamic/*=ZoneUnaryCallback<R, dynamic>*/);
   }
 }
