@@ -96,7 +96,9 @@ class Error {
  * Error thrown by the runtime system when an assert statement fails.
  */
 class AssertionError extends Error {
-  AssertionError();
+  /** Message describing the assertion error. */
+  final Object message;
+  AssertionError([this.message]);
   String toString() => "Assertion failed";
 }
 
@@ -220,7 +222,7 @@ class RangeError extends ArgumentError {
                     (message != null) ? message : "Value not in range");
 
   /**
-   * Create a new [RangeError] with for an invalid value being outside a range.
+   * Create a new [RangeError] for a value being outside the valid range.
    *
    * The allowed range is from [minValue] to [maxValue], inclusive.
    * If `minValue` or `maxValue` are `null`, the range is infinite in
@@ -414,6 +416,8 @@ class IndexError extends ArgumentError implements RangeError {
  */
 class FallThroughError extends Error {
   FallThroughError();
+
+  external String toString();
 }
 
 /**
@@ -421,8 +425,9 @@ class FallThroughError extends Error {
  */
 class AbstractClassInstantiationError extends Error {
   final String _className;
-  AbstractClassInstantiationError(String this._className);
-  String toString() => "Cannot instantiate abstract class: '$_className'";
+  AbstractClassInstantiationError(String className) : _className = className;
+
+  external String toString();
 }
 
 
@@ -459,16 +464,11 @@ class NoSuchMethodError extends Error {
    * the signature of the method that would have been called if the parameters
    * had matched.
    */
-  NoSuchMethodError(Object receiver,
-                    Symbol memberName,
-                    List positionalArguments,
-                    Map<Symbol ,dynamic> namedArguments,
-                    [List existingArgumentNames = null])
-      : _receiver = receiver,
-        _memberName = memberName,
-        _arguments = positionalArguments,
-        _namedArguments = namedArguments,
-        _existingArgumentNames = existingArgumentNames;
+  external NoSuchMethodError(Object receiver,
+                             Symbol memberName,
+                             List positionalArguments,
+                             Map<Symbol, dynamic> namedArguments,
+                             [List existingArgumentNames = null]);
 
   external String toString();
 }
