@@ -120,8 +120,8 @@ class _HttpDetachedStreamSubscription implements StreamSubscription<List<int>> {
 
   bool get isPaused => _subscription.isPaused;
 
-  Future/*<T>*/ asFuture/*<T>*/([/*=T*/ futureValue]) =>
-      _subscription.asFuture/*<T>*/(futureValue);
+  Future<T> asFuture<T>([T futureValue]) =>
+      _subscription.asFuture<T>(futureValue);
 
   Future cancel() {
     _isCanceled = true;
